@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # Copyright (c) 2009, Willow Garage, Inc.
 # All rights reserved.
 #
@@ -73,6 +72,7 @@ from .rosdistrohelper import PreRep137Warning
 from .catkin_packages import find_catkin_packages_in
 from .catkin_packages import set_workspace_packages
 from .catkin_packages import get_workspace_packages
+from catkin_pkg.package import InvalidPackage
 
 
 class UsageError(Exception):
@@ -175,6 +175,9 @@ ERROR: %s
     except UnsupportedOs as e:
         print('Unsupported OS: %s\nSupported OSes are [%s]' % (e.args[0], ', '.join(e.args[1])), file=sys.stderr)
         sys.exit(1)
+    except InvalidPackage as e:
+        print(str(e))
+        sys.exit(1)
     except Exception as e:
         print("""
 ERROR: Rosdep experienced an error: %s
@@ -326,6 +329,11 @@ def _rosdep_main(args):
                       'whether sudo is used for a specific installer, '
                       "e.g. '--as-root pip:false' or '--as-root \"pip:no homebrew:yes\"'. "
                       'Can be specified multiple times.')
+    parser.add_option('--include-eol-distros', dest='include_eol_distros',
+                      default=False, action='store_true',
+                      help="Affects the 'update' verb. "
+                           'If specified end-of-life distros are being '
+                           'fetched too.')
 
     options, args = parser.parse_args(args)
     if options.print_version or options.print_all_versions:
@@ -339,7 +347,7 @@ def _rosdep_main(args):
         installer_keys = get_default_installer()[1]
         version_strings = []
         for key in installer_keys:
-            if key is 'source':
+            if key == 'source':
                 # Explicitly skip the source installer.
                 continue
             installer = installers[key]
@@ -589,7 +597,8 @@ def command_update(options):
             # nothing we wanna do under Windows
             pass
         update_sources_list(success_handler=update_success_handler,
-                            error_handler=update_error_handler)
+                            error_handler=update_error_handler,
+                            skip_eol_distros=not options.include_eol_distros)
         print('updated cache in %s' % (sources_cache_dir))
     except InvalidData as e:
         print('ERROR: invalid sources list file:\n\t%s' % (e), file=sys.stderr)
@@ -631,13 +640,13 @@ def command_check(lookup, packages, options):
 
     # pretty print the result
     if [v for k, v in uninstalled if v]:
-        print('System dependencies have not been satisified:')
+        print('System dependencies have not been satisfied:')
         for installer_key, resolved in uninstalled:
             if resolved:
                 for r in resolved:
                     print('%s\t%s' % (installer_key, r))
     else:
-        print('All system dependencies have been satisified')
+        print('All system dependencies have been satisfied')
     if errors:
         for package_name, ex in errors.items():
             if isinstance(ex, rospkg.ResourceNotFound):
