@@ -124,7 +124,7 @@ class TestRosdepMain(unittest.TestCase):
                 assert False, 'system exit occurred: %s\n%s' % (b[0].getvalue(), b[1].getvalue())
 
             stdout, stderr = b
-            assert stdout.getvalue().strip() == 'All system dependencies have been satisified', stdout.getvalue()
+            assert stdout.getvalue().strip() == 'All system dependencies have been satisfied', stdout.getvalue()
             assert not stderr.getvalue(), stderr.getvalue()
         try:
             osd = rospkg.os_detect.OsDetect()
@@ -132,7 +132,7 @@ class TestRosdepMain(unittest.TestCase):
             with fakeout() as b:
                 rosdep_main(['check', 'python_dep', '--os', override] + cmd_extras)
                 stdout, stderr = b
-                assert stdout.getvalue().strip() == 'All system dependencies have been satisified'
+                assert stdout.getvalue().strip() == 'All system dependencies have been satisfied'
                 assert not stderr.getvalue(), stderr.getvalue()
         except SystemExit:
             assert False, 'system exit occurred'
@@ -142,7 +142,7 @@ class TestRosdepMain(unittest.TestCase):
             with fakeout() as b:
                 rosdep_main(['check', 'packageless'] + cmd_extras)
                 stdout, stderr = b
-                assert stdout.getvalue().strip() == 'All system dependencies have been satisified'
+                assert stdout.getvalue().strip() == 'All system dependencies have been satisfied'
                 assert not stderr.getvalue(), stderr.getvalue()
         except SystemExit:
             assert False, 'system exit occurred'
@@ -275,3 +275,15 @@ class TestRosdepMain(unittest.TestCase):
         with patch.dict('os.environ', {'https_proxy': 'somethings'}, clear=True):
             setup_proxy_opener()
             proxy.assert_called_with({'https': 'somethings'})
+
+    def test_invalid_package_message(self):
+        with fakeout() as b:
+            test_package_dir = os.path.abspath(os.path.join(get_test_dir(), 'main', 'invalid_package_version'))
+            with patch('rosdep2.main.sys.exit') as exit_mock:
+                rosdep_main(['install', '--from-path', test_package_dir])
+                exit_mock.assert_called_with(1)
+            stdout, stderr = b
+            output = stdout.getvalue().splitlines()
+            assert len(output) == 2
+            assert test_package_dir in output[0]
+            assert 'Package version ":{version}" does not follow version conventions' in output[1]
